@@ -9,7 +9,7 @@ use Exporter 'import';
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
 our $DATE = '2022-12-09'; # DATE
 our $DIST = 'Perinci-Sub-Normalize'; # DIST
-our $VERSION = '0.205'; # VERSION
+our $VERSION = '0.206'; # VERSION
 
 our @EXPORT_OK = qw(
                        normalize_function_metadata
@@ -37,7 +37,7 @@ sub _check {
                     $slurpy_pos = $argspec->{pos};
                 }
             }
-            if (defined $slurpy_pos && $slurpy_pos < @pos) {
+            if (defined $slurpy_pos && $slurpy_pos < @pos-1) {
                 return "Clash of argument positions: slurpy=1 defined for pos=$slurpy_pos but there is another argument with pos > $slurpy_pos";
             }
             # we have holes
@@ -208,7 +208,7 @@ Perinci::Sub::Normalize - Normalize Rinci function metadata
 
 =head1 VERSION
 
-This document describes version 0.205 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2022-12-09.
+This document describes version 0.206 of Perinci::Sub::Normalize (from Perl distribution Perinci-Sub-Normalize), released on 2022-12-09.
 
 =head1 SYNOPSIS
 
